AdvancedGraphviewController class

AdvancedGraphviewController will control the state of the widget

Inheritance

Constructors

AdvancedGraphviewController()
AdvancedGraphviewController will control the state of the widget

Properties

cachedGraphNode ↔ GraphNode?
cachedGraphNode stores the cache
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
maxScrollExtent ↔ double?
maxScrollExtent max scroll extent in canvas
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollX ↔ double?
scrollX give it to control the scroll in canvas
getter/setter pair
scrollY ↔ double?
scrollY give it to control the scroll in canvas
getter/setter pair
value ↔ dynamic
The current value stored in this notifier.
getter/setter pairinherited
zoom ↔ double?
zoom zoom level in canvas
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearCache() → void
clearCache clear the cache
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setScroll({double? scrollX, double? scrollY}) → void
setScroll will scroll the in canvas
setZoomValue({double? zoom}) → void
setZoomValue zoom level in canvas
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited