GraphNode class abstract

Constructors

GraphNode()

Properties

cachedPosition ↔ Offset?
this is the cached position if this position is passed then it will get cached and then position can be reused instead of regenerating the whole node position randomly
getter/setter pair
graphNodes → List<GraphNode>
graphNodes takes the list of children that will be used to traverse further
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
id represents the uniqueness of the node. id is used to link nodes. children id must not be same as parent to avoid self looping.
no setter
item ↔ NodeModuleItem?
item is the configuration of the node UI if we pass this then based on the configuration the node will be rendered this is optional
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited