AdvancedGraphviewWidget<T extends GraphNode> class

AdvancedGraphviewWidget will create tree structured nodes

Inheritance

Constructors

AdvancedGraphviewWidget({Key? key, required double nodePadding, required double nodeSize, required GraphNode graphNode, required Widget builder(T graphNode), bool isDebug = false, AdvancedGraphviewController? advancedGraphviewController, Paint? onDrawLine(T lineFrom, T lineTwo)?, Color? backgroundColor, double pixelRatio = 1, dynamic onNodeTap(GraphNode)?})
AdvancedGraphviewWidget will create tree structured nodes
const

Properties

advancedGraphviewController → AdvancedGraphviewController?
advancedGraphviewController will give you the control to handle state
final
backgroundColor → Color?
set the background color of the canvas
final
builder → Widget Function(T graphNode)
builder pass the widget that has to be rendered in tree children note : Only static widget can be passed animating or widget which keeps changing its state will not be rendered.
final
graphNode → GraphNode
nodeSize this is the Head of the tree(first parent of the tree)
final
hashCode → int
The hash code for this object.
no setterinherited
isDebug → bool
isDebug will show the wireframe
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nodePadding → double
nodeSize represents padding between the nodes
final
nodeSize → double
nodeSize represents the size of the node
final
onDrawLine → Paint? Function(T lineFrom, T lineTwo)?
isDebug decide the paint needed to draw the line
final
onNodeTap → dynamic Function(GraphNode)?
action when you tap a node
final
pixelRatio → double
pixel ratio sets the widget pixel ratio
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AdvancedGraphviewWidget<GraphNode>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

context ↔ BuildContext
getter/setter pair